Welcome
=======

This contains the API reference for the `pydoover` Python package, a library for interacting with Doover and managing applications on devices.

It is designed to be used in conjunction with the Doover CLI, which provides a command-line interface for managing Doover applications and devices.

For a quickstart and tutorials, please see the main Doover documentation at `docs.doover.com <https://docs.doover.com>`_.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

Contents
--------

.. toctree::
    :maxdepth: 2
    :caption: Getting Started

    installation
    changelog

.. toctree::
    :maxdepth: 2
    :caption: Applications

    applications/docker
    applications/processor
    applications/config_schema

.. toctree::
    :maxdepth: 2
    :caption: Docker Interfaces

    docker/device_agent
    docker/platform
    docker/modbus

.. toctree::
    :maxdepth: 2
    :caption: Reports

    reports

.. toctree::
    :maxdepth: 2
    :caption: User Interfaces

    ui

.. toctree::
    :maxdepth: 2
    :caption: API Client

    api/client
    api/models
    api/exceptions

.. toctree::
    :maxdepth: 2
    :caption: Utilities

    utils
